@@ -3,9 +3,9 @@ from django.db import models
 
 class AbstractFormSetting(models.Model):
     form = models.OneToOneField(
-        'wagtailstreamforms.Form',
+        "wagtailstreamforms.Form",
         on_delete=models.CASCADE,
-        related_name='advanced_settings'
+        related_name="advanced_settings",
     )
 
     class Meta:
