@@ -1,6 +1,5 @@
 from django.apps import apps
 from django.core.exceptions import ImproperlyConfigured
-
 from wagtailstreamforms.conf import get_setting
 from wagtailstreamforms.models import AbstractFormSetting
 
@@ -10,14 +9,14 @@ def get_advanced_settings_model():
     Returns the advanced form settings model if one is defined
     """
 
-    model = get_setting('ADVANCED_SETTINGS_MODEL')
+    model = get_setting("ADVANCED_SETTINGS_MODEL")
 
     if not model:
         return
 
     def raise_error(msg):
-        setting = 'WAGTAILSTREAMFORMS_ADVANCED_SETTINGS_MODEL'
-        raise ImproperlyConfigured('%s %s' % (setting, msg))
+        setting = "WAGTAILSTREAMFORMS_ADVANCED_SETTINGS_MODEL"
+        raise ImproperlyConfigured("%s %s" % (setting, msg))
 
     try:
         model_class = apps.get_model(model, require_ready=False)
